# Eviction split

Alliance auth module dedicated to splitting the loot of an eviction between participants based on their participation time.

**Insert tags**


## TODO:

- [ ] Enhance the signup so applicants specify what they bring to the eviction
- [ ] Interface to split loot by the end of an eviction
- [ ] Logging!!!!

## Features:

 - Create and manage evictions
 - Apply to join an eviction
 - Signal the current activity of members (standby and/or doorstopping)


## Screenshots

TODO


## Installation

TODO

## Permissions

|      ID      |           Description           |                            Notes                            |
|:------------:|:-------------------------------:|:-----------------------------------------------------------:|
| basic_access |       Can access this app       |           All line members should have this role            |
|   manager    | Can create and manage evictions | Role to create/edit evictions and access archived evictions |
